---
title: <span class="badge builder"></span> HeatmapLegend
---
# <span class="badge builder"></span> HeatmapLegend

## Constructor

```python
HeatmapLegend()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.HeatmapLegend
```

### <span class="badge object-method"></span> show

Controls if the legend is shown

```python
def show(show: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HeatmapLegend](./object-HeatmapLegend.md)
